@@ -50,8 +50,8 @@ class HTTPSSHHandler(AbstractHTTPHandler):
 
 # upload.py in 2.7 insists on only supporting http and https URLs
 # Fake one, and make urlopen replace that with a httpssh URL
-_goodprefix = 'httpssh://submit@pypi.python.org/pypi'
-_badprefix = 'http://submit@pypi.python.org/pypi'
+_goodprefix = 'httpssh://submit@ssh.pypi.python.org/pypi'
+_badprefix = 'http://submit@ssh.pypi.python.org/pypi'
 class PyPIOpenerDirector(OpenerDirector):
     def open(self, req, data=None):
         if isinstance(req, basestring):
@@ -69,6 +69,7 @@ class PyPIOpenerDirector(OpenerDirector):
 # so we have to patch the entire upload_file implementation
 if sys.version_info < (2,7):
     from distutils import log
+    from distutils.spawn import spawn
     from hashlib import md5
     from base64 import standard_b64encode
     import cStringIO as StringIO
